@@ -1,7 +1,7 @@
 /*
  * float.h - auxilirary floating-point number support
  *
- *   Copyright (c) 2007-2018  Shiro Kawai  <shiro@acm.org>
+ *   Copyright (c) 2007-2019  Shiro Kawai  <shiro@acm.org>
  *
  *   Redistribution and use in source and binary forms, with or without
  *   modification, are permitted provided that the following conditions
@@ -40,6 +40,8 @@
 #define GAUCHE_FLOAT_H
 
 #include <math.h>
+#include <complex.h>
+#undef I                        /* avoid unintentional conflict */
 
 #if defined(HAVE_FPU_CONTROL_H)
 #include <fpu_control.h>
@@ -66,6 +68,14 @@ typedef unsigned short  ScmHalfFloat;
      && !SCM_HALF_FLOAT_IS_NAN(hf2)             \
      && ((hf1) op (hf2)))
 
+typedef struct {
+    ScmHalfFloat r;
+    ScmHalfFloat i;
+} ScmHalfComplex;
+
+#define SCM_HALF_COMPLEX_REAL(hc)  ((hc).r)
+#define SCM_HALF_COMPLEX_IMAG(hc)  ((hc).i)
+
 /*
  * Long double support
  */
