@@ -1,7 +1,7 @@
 /*
  * number.h - Public API for Scheme numbers
  *
- *   Copyright (c) 2000-2018  Shiro Kawai  <shiro@acm.org>
+ *   Copyright (c) 2000-2019  Shiro Kawai  <shiro@acm.org>
  *
  *   Redistribution and use in source and binary forms, with or without
  *   modification, are permitted provided that the following conditions
@@ -58,6 +58,7 @@
     (((k)<=SCM_SMALL_INT_MAX)&&((k)>=SCM_SMALL_INT_MIN))
 
 #define SCM_RADIX_MAX              36
+#define SCM_RADIX_MIN              2
 
 #define SCM_INTEGERP(obj)          (SCM_INTP(obj) || SCM_BIGNUMP(obj))
 #define SCM_RATIONALP(obj)         (SCM_INTEGERP(obj)||SCM_RATNUMP(obj))
@@ -207,10 +208,10 @@ SCM_EXTERN u_long Scm_GetIntegerUMod(ScmObj obj);
 
 /* 64bit integer stuff */
 #if SIZEOF_LONG == 4
-SCM_EXTERN ScmObj Scm_MakeInteger64(ScmInt64 i);
-SCM_EXTERN ScmObj Scm_MakeIntegerU64(ScmUInt64 i);
-SCM_EXTERN ScmInt64  Scm_GetInteger64Clamp(ScmObj obj, int clamp, int *oor);
-SCM_EXTERN ScmUInt64 Scm_GetIntegerU64Clamp(ScmObj obj, int clamp, int *oor);
+SCM_EXTERN ScmObj Scm_MakeInteger64(int64_t i);
+SCM_EXTERN ScmObj Scm_MakeIntegerU64(uint64_t i);
+SCM_EXTERN int64_t  Scm_GetInteger64Clamp(ScmObj obj, int clamp, int *oor);
+SCM_EXTERN uint64_t Scm_GetIntegerU64Clamp(ScmObj obj, int clamp, int *oor);
 #else  /* SIZEOF_LONG >= 8 */
 #define Scm_MakeInteger64      Scm_MakeInteger
 #define Scm_MakeIntegerU64     Scm_MakeIntegerU
@@ -256,6 +257,12 @@ SCM_EXTERN ScmHalfFloat Scm_DoubleToHalf(double v);
 SCM_EXTERN ScmObj Scm_MakeCompnum(double real, double imag);
 SCM_EXTERN ScmObj Scm_MakeComplex(double real, double imag);
 SCM_EXTERN ScmObj Scm_MakeComplexPolar(double magnitude, double angle);
+SCM_EXTERN ScmHalfComplex Scm_GetHalfComplex(ScmObj obj);
+SCM_EXTERN complex float  Scm_GetFloatComplex(ScmObj obj);
+SCM_EXTERN complex double Scm_GetDoubleComplex(ScmObj obj);
+SCM_EXTERN ScmObj Scm_HalfComplexToComplex(const ScmHalfComplex c);
+SCM_EXTERN ScmObj Scm_FloatComplexToComplex(const complex float c);
+SCM_EXTERN ScmObj Scm_DoubleComplexToComplex(const complex double c);
 
 SCM_EXTERN int    Scm_IntegerP(ScmObj obj);
 SCM_EXTERN int    Scm_OddP(ScmObj obj);
@@ -341,13 +348,15 @@ enum ScmNumberFormatFlags {
                                               between N and S:
                                               [N] always add radix prefix
                                               [S] never allow radix prefix */
-    SCM_NUMBER_FORMAT_ROUND_NOTATIONAL = (1L<<3)
+    SCM_NUMBER_FORMAT_ROUND_NOTATIONAL = (1L<<3),
                                            /* Using notational decimal rounding.
                                               [N] When rounding fractional part,
                                               we first generate the closest
                                               decimal notation, then round.
                                               [S] ignored.
                                             */
+    SCM_NUMBER_FORMAT_STRICT_R7RS = (1L<<4) /*[N] ignored.
+                                              [S] reject syntax outside of R7RS*/
 };
 
 typedef struct ScmNumberFormatRec {
@@ -356,6 +365,7 @@ typedef struct ScmNumberFormatRec {
     int precision;    /* # of digits after decimal point, -1 for unlimited */
     int exp_lo;       /* use exp notation if exponent <= exp_lo */
     int exp_hi;       /* use exp notation if exponent >= exp_hi */
+    int exp_width;    /* min # of digits used for exponent */
 } ScmNumberFormat;
 
 SCM_EXTERN void   Scm_NumberFormatInit(ScmNumberFormat*);
