@@ -1,7 +1,7 @@
 ;;;
 ;;; gauche.cgen.type - type management
 ;;;
-;;;   Copyright (c) 2004-2018  Shiro Kawai  <shiro@acm.org>
+;;;   Copyright (c) 2004-2019  Shiro Kawai  <shiro@acm.org>
 ;;;
 ;;;   Redistribution and use in source and binary forms, with or without
 ;;;   modification, are permitted provided that the following conditions
@@ -216,17 +216,20 @@
    (<list> "ScmObj" "list" "SCM_LISTP" "")
    (<vector> "ScmVector*" "vector" "SCM_VECTORP" "SCM_VECTOR")
    (<uvector> "ScmUVector*" "uniform vector" "SCM_UVECTORP" "SCM_UVECTOR")
-   (<s8vector> "ScmS8Vector*" "s8vector" "SCM_S8VECTORP" "SCM_S8VECTOR")
-   (<u8vector> "ScmU8Vector*" "u8vector" "SCM_U8VECTORP" "SCM_U8VECTOR")
-   (<s16vector> "ScmS16Vector*" "s16vector" "SCM_S16VECTORP" "SCM_S16VECTOR")
-   (<u16vector> "ScmU16Vector*" "u16vector" "SCM_U16VECTORP" "SCM_U16VECTOR")
-   (<s32vector> "ScmS32Vector*" "s32vector" "SCM_S32VECTORP" "SCM_S32VECTOR")
-   (<u32vector> "ScmU32Vector*" "u32vector" "SCM_U32VECTORP" "SCM_U32VECTOR")
-   (<s64vector> "ScmS64Vector*" "s64vector" "SCM_S64VECTORP" "SCM_S64VECTOR")
-   (<u64vector> "ScmU64Vector*" "u64vector" "SCM_U64VECTORP" "SCM_U64VECTOR")
-   (<f16vector> "ScmF16Vector*" "f16vector" "SCM_F16VECTORP" "SCM_F16VECTOR")
-   (<f32vector> "ScmF32Vector*" "f32vector" "SCM_F32VECTORP" "SCM_F32VECTOR")
-   (<f64vector> "ScmF64Vector*" "f64vector" "SCM_F64VECTORP" "SCM_F64VECTOR")
+   (<s8vector> "ScmUVector*" "s8vector" "SCM_S8VECTORP" "SCM_S8VECTOR")
+   (<u8vector> "ScmUVector*" "u8vector" "SCM_U8VECTORP" "SCM_U8VECTOR")
+   (<s16vector> "ScmUVector*" "s16vector" "SCM_S16VECTORP" "SCM_S16VECTOR")
+   (<u16vector> "ScmUVector*" "u16vector" "SCM_U16VECTORP" "SCM_U16VECTOR")
+   (<s32vector> "ScmUVector*" "s32vector" "SCM_S32VECTORP" "SCM_S32VECTOR")
+   (<u32vector> "ScmUVector*" "u32vector" "SCM_U32VECTORP" "SCM_U32VECTOR")
+   (<s64vector> "ScmUVector*" "s64vector" "SCM_S64VECTORP" "SCM_S64VECTOR")
+   (<u64vector> "ScmUVector*" "u64vector" "SCM_U64VECTORP" "SCM_U64VECTOR")
+   (<f16vector> "ScmUVector*" "f16vector" "SCM_F16VECTORP" "SCM_F16VECTOR")
+   (<f32vector> "ScmUVector*" "f32vector" "SCM_F32VECTORP" "SCM_F32VECTOR")
+   (<f64vector> "ScmUVector*" "f64vector" "SCM_F64VECTORP" "SCM_F64VECTOR")
+   (<c32vector> "ScmUVector*" "c32vector" "SCM_C32VECTORP" "SCM_C32VECTOR")
+   (<c64vector> "ScmUVector*" "c64vector" "SCM_C64VECTORP" "SCM_C64VECTOR")
+   (<c128vector> "ScmUVector*" "c128vector" "SCM_C128VECTORP" "SCM_C128VECTOR")
    (<string> "ScmString*" "string" "SCM_STRINGP" "SCM_STRING")
    (<symbol> "ScmSymbol*" "symbol" "SCM_SYMBOLP" "SCM_SYMBOL")
    (<keyword> "ScmKeyword*" "keyword" "SCM_KEYWORDP" "SCM_KEYWORD")
