@@ -1,7 +1,7 @@
 ;;;
 ;;; process.scm - process interface
 ;;;
-;;;   Copyright (c) 2000-2018  Shiro Kawai  <shiro@acm.org>
+;;;   Copyright (c) 2000-2019  Shiro Kawai  <shiro@acm.org>
 ;;;
 ;;;   Redistribution and use in source and binary forms, with or without
 ;;;   modification, are permitted provided that the following conditions
@@ -452,15 +452,15 @@
                  (zero? (sys-wait-exit-status status)))
       (cond [(sys-wait-exited? status)
              (errorf <process-abnormal-exit> :process process
-                     "~s exitted abnormally with exit code ~a"
+                     "~s exited abnormally with exit code ~a"
                      process (sys-wait-exit-status status))]
             [(sys-wait-signaled? status)
              (errorf <process-abnormal-exit> :process process
-                     "~s exitted by signal ~s"
+                     "~s exited by signal ~s"
                      process (sys-signal-name (sys-wait-termsig status)))]
             [else ;; we shouldn't be here, but just in case...
              (errorf <process-abnormal-exit> :process process
-                     "~s exitted abnormally with status ~s"
+                     "~s exited abnormally with status ~s"
                      process status)]))))
 
 ;; other basic interfaces
@@ -565,7 +565,7 @@
     (process-wait p #f eflag)
     (zero? (process-exit-status p))))
 
-;; For the backward compatiblity.  DEPRECATED.
+;; For the backward compatibility.  DEPRECATED.
 (define (run-process-pipeline . args) ; returns list of processes.
   (let1 p (apply run-pipeline args)
     (append (~ p'upstreams) (list p))))
